@@ -19,16 +19,14 @@
 
 #define VGA_DEFAULT_LINEBYTES	(VGA_DEFAULT_WIDTH*((VGA_DEFAULT_DEPTH+7)/8))
 
-void setup_video(phys_addr_t phys, ucell virt);
+void setup_video(void);
 unsigned long video_get_color(int col_ind);
-void video_set_color(int ind, unsigned long color);
 void video_mask_blit(void);
 void video_invert_rect(void);
 void video_fill_rect(void);
 
 extern struct video_info {
     volatile ihandle_t *ih;
-    volatile phys_addr_t mphys;
     volatile ucell *mvirt;
     volatile ucell *rb, *w, *h, *depth;
 
