@@ -41,6 +41,8 @@
 #include <common.h>
 #include <dm.h>
 #include <i2c.h>
+#include <log.h>
+#include <linux/delay.h>
 
 #include <asm/io.h>
 #include <asm/omap_i2c.h>
@@ -306,7 +308,7 @@ static int __omap24_i2c_setspeed(void __iomem *i2c_base, int ip_rev, uint speed,
 	int hsscll = 0, hssclh = 0;
 	u32 scll = 0, sclh = 0;
 
-	if (speed >= OMAP_I2C_HIGH_SPEED) {
+	if (speed >= I2C_SPEED_HIGH_RATE) {
 		/* High speed */
 		psc = I2C_IP_CLK / I2C_INTERNAL_SAMPLING_CLK;
 		psc -= 1;
@@ -834,7 +836,7 @@ wr_exit:
 	return i2c_error;
 }
 
-#ifndef CONFIG_DM_I2C
+#if !CONFIG_IS_ENABLED(DM_I2C)
 /*
  * The legacy I2C functions. These need to get removed once
  * all users of this driver are converted to DM.
@@ -1047,7 +1049,7 @@ static int omap_i2c_probe_chip(struct udevice *bus, uint chip_addr,
 static int omap_i2c_probe(struct udevice *bus)
 {
 	struct omap_i2c *priv = dev_get_priv(bus);
-	struct omap_i2c_platdata *plat = dev_get_platdata(bus);
+	struct omap_i2c_plat *plat = dev_get_plat(bus);
 
 	priv->speed = plat->speed;
 	priv->regs = map_physmem(plat->base, sizeof(void *),
@@ -1061,12 +1063,13 @@ static int omap_i2c_probe(struct udevice *bus)
 }
 
 #if CONFIG_IS_ENABLED(OF_CONTROL) && !CONFIG_IS_ENABLED(OF_PLATDATA)
-static int omap_i2c_ofdata_to_platdata(struct udevice *bus)
+static int omap_i2c_of_to_plat(struct udevice *bus)
 {
-	struct omap_i2c_platdata *plat = dev_get_platdata(bus);
+	struct omap_i2c_plat *plat = dev_get_plat(bus);
 
-	plat->base = devfdt_get_addr(bus);
-	plat->speed = dev_read_u32_default(bus, "clock-frequency", 100000);
+	plat->base = dev_read_addr(bus);
+	plat->speed = dev_read_u32_default(bus, "clock-frequency",
+					   I2C_SPEED_STANDARD_RATE);
 	plat->ip_rev = dev_get_driver_data(bus);
 
 	return 0;
@@ -1090,11 +1093,11 @@ U_BOOT_DRIVER(i2c_omap) = {
 	.id	= UCLASS_I2C,
 #if CONFIG_IS_ENABLED(OF_CONTROL) && !CONFIG_IS_ENABLED(OF_PLATDATA)
 	.of_match = omap_i2c_ids,
-	.ofdata_to_platdata = omap_i2c_ofdata_to_platdata,
-	.platdata_auto_alloc_size = sizeof(struct omap_i2c_platdata),
+	.of_to_plat = omap_i2c_of_to_plat,
+	.plat_auto	= sizeof(struct omap_i2c_plat),
 #endif
 	.probe	= omap_i2c_probe,
-	.priv_auto_alloc_size = sizeof(struct omap_i2c),
+	.priv_auto	= sizeof(struct omap_i2c),
 	.ops	= &omap_i2c_ops,
 #if !CONFIG_IS_ENABLED(OF_CONTROL)
 	.flags  = DM_FLAG_PRE_RELOC,
